==> order-center-api-2.1.0-CLOUD-UAT-20220830.131257-1-sources.jar: com/tydic/dyc/oc/service/saleorder/bo/UocGetSaleOrderItemsServiceRspItemBo.java <==
package com.tydic.dyc.oc.service.saleorder.bo;

import com.tydic.utils.generatedoc.annotation.DocField;
import lombok.Data;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.Date;

/**
 * 标题:UocGetSaleOrderItemsServiceRspItemBo
 * 说明:TODO
 * 时间:2022/4/8 10:53
 * 作者:代愿愿
 */
@Data
public class UocGetSaleOrderItemsServiceRspItemBo implements Serializable {
    private static final long serialVersionUID = -2809991130811759272L;


    @DocField(value = "销售明细id")
    private Long saleOrderItemId;

    @DocField(value = "订单明细id")
    private Long orderItemId;

    @DocField(value = "明细类型             1 商品sku             2 物资             3 项目")
    private Integer itemType;

    @DocField(value = "明细类型翻译")
    private String itemTypeStr;

    @DocField(value = "单品ID")
    private String skuId;

    @DocField(value = "单品编码")
    private String skuCode;

    @DocField("单品名称")
    private String skuName;

    @DocField(value = "商品id")
    private String commodityId;

    @DocField(value = "商品编码")
    private String commodityCode;

    @DocField(value = "商品名称")
    private String commodityName;

    @DocField(value = "供应商ID")
    private String supplierId;

    @DocField(value = "店铺ID")
    private String supplierShopId;

    @DocField(value = "采购价格")
    private BigDecimal purchasePrice;

    @DocField(value = "销售价格")
    private BigDecimal salePrice;

    @DocField(value = "采购数量")
    private BigDecimal purchaseCount;

    @DocField(value = "运费")
    private BigDecimal transFee;

    @DocField(value = "采购金额")
    private BigDecimal purchaseFee;

    @DocField(value = "销售金额")
    private BigDecimal saleFee;

    @DocField(value = "应付金额")
    private BigDecimal payFee;

    @DocField(value = "积分优惠金额")
    private BigDecimal integralDisFee;

    @DocField(value = "活动优惠金额")
    private BigDecimal actDisFee;

    @DocField(value = "其它优惠金额")
    private BigDecimal otherDisFee;

    @DocField(value = "实付金额")
    private BigDecimal usedFee;

    @DocField(value = "实付积分")
    private BigDecimal usedIntegral;

    @DocField(value = "币种")
    private String currencyType;

    @DocField(value = "税金")
    private String taxPrice;

    @DocField(value = "税率")
    private String tax;

    @DocField(value = "税务编码")
    private String taxId;

    @DocField(value = "预计发货时间")
    private Date preSendTime;

    @DocField(value = "预计交货时间")
    private Date preOfferTime;

    @DocField(value = "计量单位")
    private String unitName;

    @DocField(value = "结算计量单位")
    private String settleUnit;

    @DocField(value = "售后在途数量")
    private BigDecimal afterServingCount;

    @DocField(value = "外部电商主订单id")
    private String lmOrderId;

    @DocField(value = "外部电商子订单id")
    private String lmSubOrderId;

    @DocField(value = "到货周期")
    private String arrivalTime;

    @DocField(value = "加价率")
    private Double markUpRate;

    @DocField(value = "商品服务费 ")
    private String serPrice;

    @DocField(value = "计划id")
    private String planId;

    @DocField(value = "计划明细id ")
    private String planItemId;

    @DocField(value = "计划明细编号")
    private String planItemNo;

    @DocField(value = "超验百分比，下单时保存（协议、无协议）")
    private Integer inspectionExcessPercent;

    @DocField(value = "sku物料编码")
    private String skuMaterialId;

    @DocField(value = "sku外部单品id")
    private String skuExtSkuId;

    @DocField(value = "sku品牌id")
    private Long skuBrandId;

    @DocField(value = "单品品牌名称")
    private String skuBrandName;

    @DocField(value = "sku明细id")
    private String skuItemId;

    @DocField(value = "sku物料名称")
    private String skuMaterialName;

    @DocField(value = "sku物料类型名称")
    private String skuMaterialTypeName;

    @DocField(value = "sku物料类型id")
    private String skuMaterialTypeId;

    @DocField(value = "型号")
    private String model;

    @DocField(value = "规格")
    private String spec;

    @DocField(value = "材质")
    private String texture;

    @DocField(value = "图号")
    private String figure;

    @DocField(value = "一级类目")
    private Long l1Catalog;

    @DocField(value = "二级类目")
    private Long l2Catalog;

    @DocField(value = "三级类目")
    private Long l3Catalog;

    @DocField(value = "一级类目名称")
    private String l1CatalogName;

    @DocField(value = "二级类目名称")
    private String l2CatalogName;

    @DocField(value = "三级类目名称")
    private String l3CatalogName;

    @DocField(value = "退货时间，空代表不支持")
    private Integer rejectAllowDate;

    @DocField(value = "换货时间，空代表不支持")
    private Integer exchangeAllowDate;

    @DocField(value = "维修时间，空代表不支持")
    private Integer maintainAllowDate;

    @DocField(value = "sku单品主图url")
    private String skuMainPicUrl;

    @DocField("比选单号id")
    private Long cmpOrderId;

    @DocField("比选单号")
    private String cmpOrderNo;

    @DocField("铺货单位id")
    private String distirbutionId;

    @DocField("铺货单位名称")
    private String distirbutionName;

}

==> order-center-api-3.2.2-CLOUD-UAT-20250114.041346-15-sources.jar: com/tydic/dyc/oc/service/saleorder/bo/UocGetSaleOrderItemsServiceRspItemBo.java <==
package com.tydic.dyc.oc.service.saleorder.bo;

import lombok.Data;
import lombok.EqualsAndHashCode;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.Date;

/**
 * 标题:UocGetSaleOrderItemsServiceRspItemBo
 * 说明:TODO
 * 时间:2022/4/8 10:53
 * 作者:代愿愿
 */
@Data
@EqualsAndHashCode(callSuper=false)
public class UocGetSaleOrderItemsServiceRspItemBo implements Serializable {
    private static final long serialVersionUID = -2809991130811759272L;


    /**销售明细id*/
    private Long saleOrderItemId;

    /**订单明细id*/
    private Long orderItemId;

    /**明细类型             1 商品sku             2 物资             3 项目*/
    private Integer itemType;

    /**明细类型翻译*/
    private String itemTypeStr;

    /**单品ID*/
    private String skuId;

    /**单品编码*/
    private String skuCode;

    /**单品名称*/
    private String skuName;

    /**商品id*/
    private String commodityId;

    /**商品编码*/
    private String commodityCode;

    /**商品名称*/
    private String commodityName;

    /**供应商ID*/
    private String supplierId;

    /**店铺ID*/
    private String supplierShopId;

    /**采购价格*/
    private BigDecimal purchasePrice;

    /**销售价格*/
    private BigDecimal salePrice;

    /**采购数量*/
    private BigDecimal purchaseCount;

    /**运费*/
    private BigDecimal transFee;

    /**采购金额*/
    private BigDecimal purchaseFee;

    /**销售金额*/
    private BigDecimal saleFee;

    /**应付金额*/
    private BigDecimal payFee;

    /**积分优惠金额*/
    private BigDecimal integralDisFee;

    /**活动优惠金额*/
    private BigDecimal actDisFee;

    /**其它优惠金额*/
    private BigDecimal otherDisFee;

    /**实付金额*/
    private BigDecimal usedFee;

    /**实付积分*/
    private BigDecimal usedIntegral;

    /**币种*/
    private String currencyType;

    /**税金*/
    private String taxPrice;

    /**税率*/
    private String tax;

    /**税务编码*/
    private String taxId;

    /**预计发货时间*/
    private Date preSendTime;

    /**预计交货时间*/
    private Date preOfferTime;

    /**计量单位*/
    private String unitName;

    /**结算计量单位*/
    private String settleUnit;

    /**售后在途数量*/
    private BigDecimal afterServingCount;

    /**外部电商主订单id*/
    private String lmOrderId;

    /**外部电商子订单id*/
    private String lmSubOrderId;

    /**到货周期*/
    private String arrivalTime;

    /**加价率*/
    private Double markUpRate;

    /**商品服务费 */
    private String serPrice;

    //京能新增参数开始  ///////////////////////////
    /**
     * 计划ID
     */
    private String planId;
    /**
     * 计划编号
     */
    private String planNo;
    /**
     * 计划明细ID
     */
    private String planItemId;
    /**
     * 计划明细编号
     */
    private String planItemNo;
    /**
     * 计划来源1SAP;2电商平台
     */
    private Integer planSource;
    /**
     * 计划单位
     */
    private String planUnit;
    /**
     * 单位转换倍率
     */
    private BigDecimal planConversionRate;
    /**
     * 计划扣减数量
     */
    private BigDecimal planDeductCount;
    //京能新增参数开始  ///////////////////////////

    /**超验百分比，下单时保存（协议、无协议）*/
    private Integer inspectionExcessPercent;

    /**sku物料编码*/
    private String skuMaterialId;

    //sku物料编码")
    private String skuMaterialCode;

    /**sku外部单品id*/
    private String skuExtSkuId;

    /**sku品牌id*/
    private Long skuBrandId;

    /**单品品牌名称*/
    private String skuBrandName;

    /**sku明细id*/
    private String skuItemId;

    /**sku物料名称*/
    private String skuMaterialName;

    /**sku物料类型名称*/
    private String skuMaterialTypeName;

    /**sku物料类型id*/
    private String skuMaterialTypeId;

    /**型号*/
    private String model;

    /**规格*/
    private String spec;

    /**材质*/
    private String texture;

    /**图号*/
    private String figure;

    /**一级类目*/
    private Long l1Catalog;

    /**二级类目*/
    private Long l2Catalog;

    /**三级类目*/
    private Long l3Catalog;

    /**一级类目名称*/
    private String l1CatalogName;

    /**二级类目名称*/
    private String l2CatalogName;

    /**三级类目名称*/
    private String l3CatalogName;

    /**退货时间，空代表不支持*/
    private Integer rejectAllowDate;

    /**换货时间，空代表不支持*/
    private Integer exchangeAllowDate;

    /**维修时间，空代表不支持*/
    private Integer maintainAllowDate;

    /**sku单品主图url*/
    private String skuMainPicUrl;

    /**比选单号id*/
    private Long cmpOrderId;

    /**比选单号*/
    private String cmpOrderNo;

    /**铺货单位id*/
    private String distirbutionId;

    /**铺货单位名称*/
    private String distirbutionName;

}
